import datetime
import json
import http.client
import ssl
import boto3
import os

class Credentials:
    def __init__(self, IOT_CERT, IOT_KEY, IOTCA_PEM, IOT_THING_NAME, IOT_ROLE_ALIAS, IOT_CREDENTIAL_ENDPOINT):
        self.proxy_host = None
        self.proxy_port = 3128
        self.iot_cert = IOT_CERT
        self.iot_key = IOT_KEY
        self.iotca_pem = IOTCA_PEM
        self.iot_thing_name = IOT_THING_NAME
        self.iot_role_alias = IOT_ROLE_ALIAS
        self.iot_credential_endpoint = IOT_CREDENTIAL_ENDPOINT
        self.credential_data = {} 
        
        self.get_credentials()
        self.get_s3_obj()

    def get_credentials(self):
        context = ssl.SSLContext(ssl.PROTOCOL_SSLv23)
        context.load_cert_chain(self.iot_cert, self.iot_key)
        context.load_verify_locations(self.iotca_pem)
        context.verify_mode = ssl.CERT_REQUIRED
        context.check_hostname = True
        headers={"x-amzn-iot-thingname": self.iot_thing_name}

        req_path = "/role-aliases/{}/credentials".format(self.iot_role_alias)
        conn = None
        json_data = None

        try:
            if self.proxy_host:
                conn = http.client.HTTPSConnection(self.proxy_host, port=self.proxy_port, context=context)
                conn.set_tunnel(self.iot_credential_endpoint, 443)
            else:
                conn = http.client.HTTPSConnection(
                    self.iot_credential_endpoint, port=443, context=context
                )

            conn.request("GET", req_path, headers=headers)
            response = conn.getresponse()
            if response.status != 200:
                print("status:{} reason:{}".format(response.status, response.reason))
            self.credential_data = json.loads(response.read())
            print(self.credential_data)
        finally:
            if conn:
                conn.close()

    def get_s3_obj(self):
        try:
            os.environ['AWS_ACCESS_KEY_ID'] = self.credential_data["credentials"]["accessKeyId"]
            os.environ['AWS_SECRET_ACCESS_KEY'] = self.credential_data["credentials"]["secretAccessKey"]
            os.environ['AWS_SESSION_TOKEN'] = self.credential_data["credentials"]["sessionToken"]
            self.s3 = boto3.client('s3')
        except:
            print("s3 created failure.")
            self.s3 = None

    def check_expiration(self):
        time_format='%Y-%m-%dT%H:%M:%SZ'
        date = datetime.datetime.now()
        expiration_date = datetime.datetime.strptime(self.credential_data["credentials"]["expiration"], time_format)
        if date >= expiration_date:
            print("get credentials() again")
            self.get_credentials()
            self.get_s3_obj()
        
    def upload_s3(self, bucket_name, upload_file, object_key):
        self.check_expiration()

        if self.s3 is not None:
            self.s3.upload_file(upload_file, bucket_name, object_key)
            print("file upload success.")

