import configparser
import os

SETTING_SECTION = "SETTING"
SE_SECTION = "SE050"

class LoadConfig:
    def __init__(self):
        path = './config.ini'
        con = configparser.ConfigParser()

        self.model = 'detect.tflite'
        self.labels = 'coco_labels.txt'
        self.camera_id = 3
        self.gateway_id = 'AAAAAAAAAAAAAAAA'
        self.threshold = 0.4
        self.wanted_labels = ["person"] 

        self.rootCA = '/root/AmazonRootCA1.pem'
        self.endpoint = 'xxxxx.iot.ap-northeast-1.amazonaws.com'
        self.cert = '/root/cert/device_cert.pem'
        self.key = '/root/cert/key.pem'
        self.port = 443
        self.credential_endpoint="xxxxx.credentials.iot.ap-northeast-1.amazonaws.com"
        self.role_alias="IoT_Device_Upload_Alias"
        self.request_delay=1
        self.s3_bucket="s3-region"

        if os.path.exists(path):
            con.read(path)

            if con.has_option(SETTING_SECTION, 'model'):
                self.model = con.get(SETTING_SECTION, 'model')
            if con.has_option(SETTING_SECTION, 'labels'):
                self.labels = con.get(SETTING_SECTION, 'labels')
            if con.has_option(SETTING_SECTION, 'camera_id'):
                self.camera_id = con.getint(SETTING_SECTION, 'camera_id')
            if con.has_option(SETTING_SECTION, 'gateway_id'):
                self.gateway_id = con.get(SETTING_SECTION, 'gateway_id')
            if con.has_option(SETTING_SECTION, 'threshold'):
                self.threshold = con.getfloat(SETTING_SECTION, 'threshold')
            if con.has_option(SETTING_SECTION, 'wanted_labels'):
                self.wanted_labels = con.get(SETTING_SECTION, 'wanted_labels')
                
            if con.has_option(SE_SECTION, 'device_data_endpoint'):
                self.endpoint = con.get(SE_SECTION, 'device_data_endpoint')
            if con.has_option(SE_SECTION, 'port'):
                self.port = con.getint(SE_SECTION, 'port')
            if con.has_option(SE_SECTION, 'rootCA'):
                self.rootCA = con.get(SE_SECTION, 'rootCA')
            if con.has_option(SE_SECTION, 'key'):
                self.key = con.get(SE_SECTION, 'key')
            if con.has_option(SE_SECTION, 'cert'):
                self.cert = con.get(SE_SECTION, 'cert')
            if con.has_option(SE_SECTION, 'credential_endpoint'):
                self.credential_endpoint = con.get(SE_SECTION, 'credential_endpoint')
            if con.has_option(SE_SECTION, 'role_alias'):
                self.role_alias = con.get(SE_SECTION, 'role_alias')
            if con.has_option(SE_SECTION, 'request_delay'):
                self.request_delay = con.getint(SE_SECTION, 'request_delay')
            if con.has_option(SE_SECTION, 's3_bucket'):
                self.s3_bucket = con.get(SE_SECTION, 's3_bucket')

    def get_model(self):
        return self.model

    def get_labels(self):
        return self.labels

    def get_camera_id(self):
        return self.camera_id

    def get_gateway_id(self):
        return self.gateway_id

    def get_threshold(self):
        return self.threshold

    def get_wanted_labels(self):
        return self.wanted_labels

    def get_host(self):
        return self.endpoint

    def get_port(self):
        return self.port

    def get_rootCA(self):
        return self.rootCA

    def get_key(self):
        return self.key

    def get_cert(self):
        return self.cert

    def get_credential_endpoint(self):
        return self.credential_endpoint

    def get_role_alias(self):
        return self.role_alias

    def get_request_delay(self):
        return self.request_delay

    def get_s3_bucket(self):
        return self.s3_bucket
