from AWSIoTPythonSDK.MQTTLib import AWSIoTMQTTShadowClient

import json

class PerformanceShadowClient:
    def __init__(self, thingName, host, port, rootCAPath, privatekeyPath, certificatePath, requestDelay):
        self.thingName = thingName
        self.host = host
        self.port = port
        self.rootCAPath = rootCAPath
        self.privatekeyPath = privatekeyPath
        self.certificatePath = certificatePath
        self.requestDelay = requestDelay
        self.mqttClient = self.configureMQTTClient() 
        self.mqttClient.connect()
        self.deviceShadowHandler = self.mqttClient.createShadowHandlerWithName(self.thingName, True)

    def shadowUpdateCallback(self, payload, responseStatus, token):
        if responseStatus == "timeout":
            print("Update request " + token + " time out!")
        if responseStatus == "accepted":
            payloadDict = json.loads(payload)
            print("~~~~~~~~~~~~~~~~~~~~~~~")
            print("Update request with token: " + token + " accepted!")
            print("property: " + str(payloadDict["state"]["desired"]["property"]))
            print("~~~~~~~~~~~~~~~~~~~~~~~\n\n")
        if responseStatus == "rejected":
            print("Update request " + token + " rejected!")

    def configureMQTTClient(self):
        mqttClient = AWSIoTMQTTShadowClient(self.thingName)
        mqttClient.configureEndpoint(self.host, self.port)
        mqttClient.configureCredentials(self.rootCAPath, self.privatekeyPath, self.certificatePath)
        mqttClient.configureAutoReconnectBackoffTime(1, 32, 20)
        mqttClient.configureConnectDisconnectTimeout(10)
        mqttClient.configureMQTTOperationTimeout(5)
        return mqttClient
    
    def updateShadow(self, payload):
        self.deviceShadowHandler.shadowUpdate(payload, self.shadowUpdateCallback, 5)

